@@ -1,3 +1,4 @@
+const os = require('os');
 const path = require('path');
 const util = require('util');
 const glob = require('glob');
@@ -42,6 +43,7 @@ class Jasmine {
   constructor(options) {
     options = options || {};
     this.loader = options.loader || new Loader();
+    this.isWindows_ = (options.platform || os.platform)() === 'win32';
     const jasmineCore = options.jasmineCore || require('jasmine-core');
 
     if (options.globals === false) {
@@ -50,7 +52,13 @@ class Jasmine {
       this.jasmine = jasmineCore.boot(jasmineCore);
     }
 
-    this.projectBaseDir = options.projectBaseDir || path.resolve();
+    if (options.projectBaseDir) {
+      this.validatePath_(options.projectBaseDir);
+      this.projectBaseDir = options.projectBaseDir;
+    } else {
+      this.projectBaseDir = (options.getcwd || path.resolve)();
+    }
+
     this.specDir = '';
     this.specFiles = [];
     this.helperFiles = [];
@@ -275,6 +283,7 @@ class Jasmine {
      * @type string | undefined
      */
     this.specDir = config.spec_dir || this.specDir;
+    this.validatePath_(this.specDir);
 
     /**
      * Whether to fail specs that contain no expectations.
@@ -311,7 +320,7 @@ class Jasmine {
      * failures.
      * @name Configuration#alwaysListPendingSpecs
      * @type boolean | undefined
-     * @default false
+     * @default true
      */
     if (config.alwaysListPendingSpecs !== undefined) {
       this.alwaysListPendingSpecs(config.alwaysListPendingSpecs);
@@ -384,6 +393,24 @@ class Jasmine {
     if(config.spec_files) {
       this.addMatchingSpecFiles(config.spec_files);
     }
+
+    /**
+     * An array of reporters. Each object in the array will be passed to
+     * {@link Jasmine#addReporter|addReporter}.
+     *
+     * This provides a middle ground between the --reporter= CLI option and full
+     * programmatic usage. Note that because reporters are objects with methods,
+     * this option can only be used in JavaScript config files
+     * (e.g `spec/support/jasmine.js`), not JSON.
+     * @name Configuration#reporters
+     * @type Reporter[] | undefined
+     * @see custom_reporter
+     */
+    if (config.reporters) {
+      for (const r of config.reporters) {
+        this.addReporter(r);
+      }
+    }
   }
 
   addRequires(requires) {
@@ -479,6 +506,16 @@ class Jasmine {
 
     return overallResult;
   }
+
+  validatePath_(path) {
+    if (this.isWindows_ && path.includes('\\')) {
+      const fixed = path.replace(/\\/g, '/');
+      console.warn('Backslashes in ' +
+        'file paths behave inconsistently between platforms and might not be ' +
+        'treated as directory separators in a future version. Consider ' +
+        `changing ${path} to ${fixed}.`);
+    }
+  }
 }
 
 /**
@@ -502,6 +539,10 @@ Jasmine.prototype.addMatchingHelperFiles = addFiles('helperFiles');
 
 function addFiles(kind) {
   return function (files) {
+    for (const f of files) {
+      this.validatePath_(f);
+    }
+
     const jasmineRunner = this;
     const fileArr = this[kind];
 
